@@ -1,4 +1,4 @@
-/* $Id: libgnomevfsmm.h,v 1.7 2003/07/21 20:54:04 mxpxpod Exp $ */
+/* $Id: libgnomevfsmm.h,v 1.11 2004/07/17 11:41:49 murrayc Exp $ */
 /* libgnomevfsmm - a C++ wrapper for libgda
  *
  * Copyright 1999-2003 Free Software Foundation
@@ -30,6 +30,8 @@ extern const int libgnomevfsmm_micro_version;
 
 #include <libgnomevfsmm/init.h>
 #include <libgnomevfsmm/application-registry.h>
+#include <libgnomevfsmm/async.h>
+#include <libgnomevfsmm/async-handle.h>
 #include <libgnomevfsmm/enums.h>
 #include <libgnomevfsmm/types.h>
 #include <libgnomevfsmm/directory-handle.h>
@@ -43,5 +45,10 @@ extern const int libgnomevfsmm_micro_version;
 #include <libgnomevfsmm/monitor-handle.h>
 #include <libgnomevfsmm/transfer-progress.h>
 #include <libgnomevfsmm/transfer.h>
+#include <libgnomevfsmm/drive.h>
+#include <libgnomevfsmm/volume.h>
+#include <libgnomevfsmm/volume-monitor.h>
+#include <libgnomevfsmm/utils.h>
+#include <libgnomevfsmm/dns-sd.h>
 
 #endif /* #ifndef LIBGNOMEVFSMM_H */
